==> mmsql-cg-lib-1.0.0.tgz: package/lib/process.js <==
const mariadb = require('mariadb');
const {log, constants} = require('utils-nxg-cg');

/**
 *
 * @param properties
 * @returns {Promise<Object>}
 */
const createConnection = async (properties = {}) => {
    return new Promise((resolve, reject) => {
        try {
            const connection = mariadb.createPool({
                //change to one minute
                connectTimeout: 60000,
                host: properties.host,
                user: properties.user,
                port: properties.port,
                password: properties.password,
                database: properties.database,
                logger: {
                    error: (err) => log.error(err)
                },
                //change to 16 mb
                maxAllowedPacket: 16777216,
            });
            resolve(connection);
        } catch (e) {
            reject(e);
        }
    });
};

/**
 *
 * @param properties
 * @returns {Promise<array|object>}
 */
const process = async (properties) => {
    return new Promise(async (resolve, reject) => {
        let connection;
        try {
            connection = await createConnection(properties);
            connection = await connection.getConnection();
            let {content, limit, query} = properties;
            let result;
            log.debug('Start transaction');
            await connection.beginTransaction();
            if (content) {
                //check if values is an array []
                if (Array.isArray(content) && content.length > 0) {
                    if (content.length > limit)
                        throw Error(`${constants.ERROR_BATCH} ${limit}`);
                    log.debug('Start batch query');
                    const arrays = Array.isArray(content[0]);
                    //if arrays then batch without namedPlaceholders
                    if (arrays)
                        result = await connection.batch(query, content);
                    else
                        result = await connection.batch({sql: query, namedPlaceholders: true}, content);
                }
                //check if values is an object {}
                else if (Object.getPrototypeOf(content) === Object.prototype && Object.keys(content).length > 0) {
                    log.debug('Start single query with values');
                    result = await connection.query({namedPlaceholders: true, sql: query}, content);
                } else {
                    log.debug('Start single query inside values');
                    result = await connection.query(query);
                }
            } else {
                log.debug('Start single query');
                result = await connection.query(query);
            }
            log.debug('Start commit');
            await connection.commit();
            log.debug('Connection end');
            await connection.release();
            resolve(processResult(result));
        } catch (e) {
            if (connection) {
                log.error('Failed, undo changes and close connection');
                await connection.rollback();
                await connection.release();
            }
            reject(e.toString());
        }
    });
};

const processResult = (result) => {
    if (Array.isArray(result)) {
        if (!result.length) return result;
        const arrays = Array.isArray(result[0]);
        if (arrays) {
            //this if is to validate is the first array is an array, if then return only first data, apply for mysql response
            if (result[0].length === 1)
                return result[0][0];
            return result[0];
        }
        if (result.length === 1)
            return result[0];
        return result;
    } else if (Object.prototype.toString.call(result) && Object.keys(result).length > 0) {
        const {affectedRows, insertId} = result;
        return {affectedRows, insertId: Number(insertId)};
    }
    return result;
}


module.exports = process;

==> mmsql-cg-lib-1.0.1.tgz: package/lib/process.js <==
const mariadb = require('mariadb');
const {log, constants, helpers} = require('utils-nxg-cg');
const {messages_databases} = constants;

/**
 *
 * @param properties
 * @returns {Promise<Object>}
 */
const createConnection = async (properties = {}) => {
    return new Promise((resolve, reject) => {
        try {
            const connection = mariadb.createPool({
                //change to one minute
                connectTimeout: 60000,
                host: properties.host,
                user: properties.user,
                port: properties.port,
                password: properties.password,
                database: properties.database,
                logger: {
                    error: (err) => log.error(err)
                },
                //change to 16 mb
                maxAllowedPacket: 16777216,
            });
            resolve(connection);
        } catch (e) {
            reject(e);
        }
    });
};

/**
 *
 * @param properties
 * @returns {Promise<array|object>}
 */
const process = async (properties) => {
    return new Promise(async (resolve, reject) => {
        let connection;
        try {
            connection = await createConnection(properties);
            connection = await connection.getConnection();
            let {content, limit, query} = properties;
            let result;
            log.debug(messages_databases.ST);
            await connection.beginTransaction();
            if (content) {
                //check if values is an array []
                if (Array.isArray(content) && content.length > 0) {
                    if (content.length > limit)
                        throw Error(`${messages_databases.ERROR_BATCH} ${limit}`);
                    log.debug(messages_databases.START_BATCH);
                    const arrays = Array.isArray(content[0]);
                    //if arrays then batch without namedPlaceholders
                    if (arrays)
                        result = await connection.batch(query, content);
                    else {
                        if (helpers.isObjectValid(content[0]))
                            result = await connection.batch({sql: query, namedPlaceholders: true}, content);
                        else
                            result = await connection.batch(query, content);
                    }
                }
                //check if values is an object {}
                else if (helpers.isObjectValid(content)) {
                    log.debug(`${messages_databases.START_QUERY} with values`);
                    result = await connection.query({namedPlaceholders: true, sql: query}, content);
                } else {
                    log.debug(`${messages_databases.START_QUERY} inside values`);
                    result = await connection.query(query);
                }
            } else {
                log.debug(messages_databases.START_QUERY);
                result = await connection.query(query);
            }
            log.debug(messages_databases.START_COMMIT);
            await connection.commit();
            log.debug(messages_databases.CONNECTION_END);
            await connection.release();
            resolve(processResult(result));
        } catch (e) {
            if (connection) {
                log.error(messages_databases.TRANSACTION_ERROR);
                await connection.rollback();
                await connection.release();
            }
            reject(e.toString());
        }
    });
};

const processResult = (result) => {
    if (Array.isArray(result)) {
        if (!result.length) return result;
        const arrays = Array.isArray(result[0]);
        if (arrays) {
            //this if is to validate is the first array is an array, if then return only first data, apply for mysql response
            if (result[0].length === 1)
                return result[0][0];
            return result[0];
        }
        if (result.length === 1)
            return result[0];
        return result;
    } else if (helpers.isObjectValid(result)) {
        const {affectedRows, insertId} = result;
        return {affectedRows, insertId: Number(insertId)};
    }
    return result;
}


module.exports = process;
